<?php

/**
 * Plugin Compositions
 * (c) Cedric Morin
 * Distribue sous licence GPL
 *
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Declaration des champs sur les objets
 *
 * @param array $tables
 * @return array
 */
function compositions_declarer_tables_objets_sql($tables) {

	// champs composition et composition_lock sur tous les objets
	// c'est easy
	$tables[]['field']['composition'] = "varchar(255) DEFAULT '' NOT NULL";
	$tables[]['field']['composition_lock'] = 'tinyint(1) DEFAULT 0 NOT NULL';
	$tables['spip_rubriques']['field']['composition_branche_lock'] = 'tinyint(1) DEFAULT 0 NOT NULL';

	return $tables;
}


/**
 * Fonction vide pour le pipeline homonyme
 */
function compositions_autoriser() {
}

/**
 * Autorisation de modifier la composition
 *
 * @param string $faire
 * @param string $type
 * @param int $id
 * @param array $qui
 * @param array $opt
 * @return bool
 */
function autoriser_styliser_dist($faire, $type = '', $id = 0, $qui = null, $opt = null) {
	include_spip('compositions_fonctions');
	if (!autoriser('modifier', $type, $id, $qui, $opt)) {
		return false;
	}
	if (compositions_verrouiller($type, $id) and !autoriser('webmestre')) {
		return false;
	}
	return true;
}


/**
 * Pipeline styliser pour definir le fond d'un objet en fonction de sa composition
 *
 * @param array $flux
 * @return array
 */
function compositions_styliser($flux) {
	// en contexte Z, c'est Z ou Z-core qui stylise (on ne n'en occupe donc pas ici)
	if (!defined('_DIR_PLUGIN_Z') and !defined('_DIR_PLUGIN_ZCORE')) {
		include_spip('compositions_fonctions');
		if (compositions_styliser_auto()) {
			$type = $flux['args']['fond']; // on fait l'approximation fond=type
			// si le type n'est pas l'objet d'une composition, ne rien faire
			if (in_array($type, compositions_types())) {
				$contexte = $flux['args']['contexte'] ?? $GLOBALS['contexte'];
				$serveur = $flux['args']['connect'];

				$ext = $flux['args']['ext'];
				$_id_table = id_table_objet($type);

				if ($id = $contexte[$_id_table] and $composition = compositions_determiner($type, $id, $serveur)) {
					if ($fond = compositions_selectionner($composition, $type, '', $ext, true, '')) {
						$flux['data'] = substr($fond, 0, - strlen(".$ext"));
					}
				}
			}
		}
	}
	return $flux;
}

/**
 * Affichage du formulaire de selection de la composition
 *
 * @param array $flux
 * @return array
 */
function compositions_affiche_milieu($flux) {
	$e = trouver_objet_exec($flux['args']['exec']);
	include_spip('compositions_fonctions');
	$objets = compositions_objets_actives();
	if (
		$e
		and in_array($e['type'], $objets)
		and $e['edition'] === false
	) {
		$type = $e['type'];
		if ($id = $flux['args'][$e['id_table_objet']]) {
			$config = (isset($GLOBALS['meta']['compositions']) ? unserialize($GLOBALS['meta']['compositions']) : []);
			$aut = autoriser('styliser', $type, $id);
			if (
				(!isset($config['masquer_formulaire']) or $config['masquer_formulaire'] != 'oui' or $aut)
				and (
					($c = compositions_lister_disponibles($type) and is_array(reset($c)))
					or ($type == 'rubrique' and (!isset($config['tout_verrouiller']) or $config['tout_verrouiller'] != 'oui'))
				  )
			) {
				$texte = recuperer_fond(
					'prive/editer/compositions',
					['type' => $type, 'id' => $id]
				);

				if (($p = strpos($flux['data'], '<!--affiche_milieu-->')) !== false) {
					$flux['data'] = substr_replace($flux['data'], $texte, $p, 0);
				} else {
					$flux['data'] .= $texte;
				}
			}
		}
	}

	return $flux;
}

/**
 * Le pipeline compositions_declarer_heritage permet de declarer les heritages
 * sous la forme :
 *		$heritages['objet'] = 'parent';
 * ce qui permet ensuite de faire dans le fichier parent-ma_compo.xml
 * <branche type="objet" composition="une_compo" />
 *
 * A partir de compositions 3.3.0 cette declaration est obligatoire.
 * Les objets "standards" de SPIP sont declares ici. (a deplacer dans leurs plugins respectifs ?)
 */
function compositions_compositions_declarer_heritage($heritages) {
	$heritages['mot'] = 'groupe_mots';
	$heritages['rubrique'] = 'rubrique';
	$heritages['article'] = 'rubrique';
	$heritages['breve'] = 'rubrique';
	$heritages['site'] = 'rubrique';
	return $heritages;
}

/**
 * Insertion dans le pipeline pre_edition (SPIP)
 *
 * Lors de la création d'une traduction d'objet, récupérer les infos de composition
 *
 * @param array $flux
 * @return array
 */
function compositions_pre_edition($flux) {
	if ($flux['args']['action'] == 'completer_traduction') {
		$champs = ['composition', 'composition_lock'];
		if ($flux['args']['type'] == 'rubrique') {
			$champs[] = 'composition_branche_lock';
		}
		/**
		 * S'assurer que les champs sont bien là pour éviter les erreurs SQL
		 */
		$trouver_table = charger_fonction('trouver_table', 'base');
		$desc = $trouver_table(table_objet_sql($flux['args']['type']));
		foreach ($champs as $champ) {
			if (empty($desc['field'][$champ])) {
				unset($champs[$champ]);
			}
		}
		if (count($champs) > 0) {
			$_id_table = id_table_objet($flux['args']['type']);
			$id_trad = sql_getfetsel('id_trad', $flux['args']['table'], $_id_table . '=' . intval($flux['args']['id_objet']));
			$set = sql_fetsel($champs, $flux['args']['table'], $_id_table . '=' . intval($id_trad));
			$flux['data'] = array_merge($flux['data'], $set);
		}
	}
	return $flux;
}
